.. _mortality_ref:

:mod:`biolearn.mortality`: Mortality Predictor Evaluation
=================================================

.. automodule:: biolearn.mortality
   :no-members:
   :no-inherited-members:

This module provides a set of functions for evaluating predictors of mortality

**Functions**:

.. currentmodule:: biolearn.mortality

.. autosummary::
   :toctree: generated/
   :template: function.rst

   run_predictions
   calculate_c_index
   calculate_mortality_hazard_ratios
   calculate_age_adjusted_c_index
   calculate_log_rank_test
   plot_hazard_ratios